==> openshift-model-5.10.1-sources.jar: io/fabric8/openshift/api/model/ResourceAccessReviewResponseFluentImpl.java <==
package io.fabric8.openshift.api.model;

import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class ResourceAccessReviewResponseFluentImpl<A extends io.fabric8.openshift.api.model.ResourceAccessReviewResponseFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.ResourceAccessReviewResponseFluent<A>{
  public ResourceAccessReviewResponseFluentImpl() {
  }
  public ResourceAccessReviewResponseFluentImpl(io.fabric8.openshift.api.model.ResourceAccessReviewResponse instance) {
    this.withApiVersion(instance.getApiVersion()); 
    this.withEvalutionError(instance.getEvalutionError()); 
    this.withGroups(instance.getGroups()); 
    this.withKind(instance.getKind()); 
    this.withNamespace(instance.getNamespace()); 
    this.withUsers(instance.getUsers()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.lang.String apiVersion;
  private java.lang.String evalutionError;
  private java.util.List<java.lang.String> groups = new java.util.ArrayList<java.lang.String>();
  private java.lang.String kind;
  private java.lang.String namespace;
  private java.util.List<java.lang.String> users = new java.util.ArrayList<java.lang.String>();
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public java.lang.String getApiVersion() {
    return this.apiVersion;
  }
  public A withApiVersion(java.lang.String apiVersion) {
    this.apiVersion=apiVersion; return (A) this;
  }
  public java.lang.Boolean hasApiVersion() {
    return this.apiVersion != null;
  }
  
  /**
   * Method is deprecated. use withApiVersion instead.
   */
  @java.lang.Deprecated
  public A withNewApiVersion(java.lang.String arg0) {
    return (A)withApiVersion(new String(arg0));
  }
  public java.lang.String getEvalutionError() {
    return this.evalutionError;
  }
  public A withEvalutionError(java.lang.String evalutionError) {
    this.evalutionError=evalutionError; return (A) this;
  }
  public java.lang.Boolean hasEvalutionError() {
    return this.evalutionError != null;
  }
  
  /**
   * Method is deprecated. use withEvalutionError instead.
   */
  @java.lang.Deprecated
  public A withNewEvalutionError(java.lang.String arg0) {
    return (A)withEvalutionError(new String(arg0));
  }
  public A addToGroups(java.lang.Integer index,java.lang.String item) {
    if (this.groups == null) {this.groups = new java.util.ArrayList<java.lang.String>();}
    this.groups.add(index, item);
    return (A)this;
  }
  public A setToGroups(java.lang.Integer index,java.lang.String item) {
    if (this.groups == null) {this.groups = new java.util.ArrayList<java.lang.String>();}
    this.groups.set(index, item); return (A)this;
  }
  public A addToGroups(java.lang.String... items) {
    if (this.groups == null) {this.groups = new java.util.ArrayList<java.lang.String>();}
    for (java.lang.String item : items) {this.groups.add(item);} return (A)this;
  }
  public A addAllToGroups(java.util.Collection<java.lang.String> items) {
    if (this.groups == null) {this.groups = new java.util.ArrayList<java.lang.String>();}
    for (java.lang.String item : items) {this.groups.add(item);} return (A)this;
  }
  public A removeFromGroups(java.lang.String... items) {
    for (java.lang.String item : items) {if (this.groups!= null){ this.groups.remove(item);}} return (A)this;
  }
  public A removeAllFromGroups(java.util.Collection<java.lang.String> items) {
    for (java.lang.String item : items) {if (this.groups!= null){ this.groups.remove(item);}} return (A)this;
  }
  public java.util.List<java.lang.String> getGroups() {
    return this.groups;
  }
  public java.lang.String getGroup(java.lang.Integer index) {
    return this.groups.get(index);
  }
  public java.lang.String getFirstGroup() {
    return this.groups.get(0);
  }
  public java.lang.String getLastGroup() {
    return this.groups.get(groups.size() - 1);
  }
  public java.lang.String getMatchingGroup(java.util.function.Predicate<java.lang.String> predicate) {
    for (java.lang.String item: groups) { if(predicate.test(item)){ return item;} } return null;
  }
  public java.lang.Boolean hasMatchingGroup(java.util.function.Predicate<java.lang.String> predicate) {
    for (java.lang.String item: groups) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withGroups(java.util.List<java.lang.String> groups) {
    if (groups != null) {this.groups = new java.util.ArrayList<java.lang.String>(); for (java.lang.String item : groups){this.addToGroups(item);}} else { this.groups = null;} return (A) this;
  }
  public A withGroups(java.lang.String... groups) {
    if (this.groups != null) {this.groups.clear();}
    if (groups != null) {for (java.lang.String item :groups){ this.addToGroups(item);}} return (A) this;
  }
  public java.lang.Boolean hasGroups() {
    return groups != null && !groups.isEmpty();
  }
  public A addNewGroup(java.lang.String arg0) {
    return (A)addToGroups(new String(arg0));
  }
  public java.lang.String getKind() {
    return this.kind;
  }
  public A withKind(java.lang.String kind) {
    this.kind=kind; return (A) this;
  }
  public java.lang.Boolean hasKind() {
    return this.kind != null;
  }
  
  /**
   * Method is deprecated. use withKind instead.
   */
  @java.lang.Deprecated
  public A withNewKind(java.lang.String arg0) {
    return (A)withKind(new String(arg0));
  }
  public java.lang.String getNamespace() {
    return this.namespace;
  }
  public A withNamespace(java.lang.String namespace) {
    this.namespace=namespace; return (A) this;
  }
  public java.lang.Boolean hasNamespace() {
    return this.namespace != null;
  }
  
  /**
   * Method is deprecated. use withNamespace instead.
   */
  @java.lang.Deprecated
  public A withNewNamespace(java.lang.String arg0) {
    return (A)withNamespace(new String(arg0));
  }
  public A addToUsers(java.lang.Integer index,java.lang.String item) {
    if (this.users == null) {this.users = new java.util.ArrayList<java.lang.String>();}
    this.users.add(index, item);
    return (A)this;
  }
  public A setToUsers(java.lang.Integer index,java.lang.String item) {
    if (this.users == null) {this.users = new java.util.ArrayList<java.lang.String>();}
    this.users.set(index, item); return (A)this;
  }
  public A addToUsers(java.lang.String... items) {
    if (this.users == null) {this.users = new java.util.ArrayList<java.lang.String>();}
    for (java.lang.String item : items) {this.users.add(item);} return (A)this;
  }
  public A addAllToUsers(java.util.Collection<java.lang.String> items) {
    if (this.users == null) {this.users = new java.util.ArrayList<java.lang.String>();}
    for (java.lang.String item : items) {this.users.add(item);} return (A)this;
  }
  public A removeFromUsers(java.lang.String... items) {
    for (java.lang.String item : items) {if (this.users!= null){ this.users.remove(item);}} return (A)this;
  }
  public A removeAllFromUsers(java.util.Collection<java.lang.String> items) {
    for (java.lang.String item : items) {if (this.users!= null){ this.users.remove(item);}} return (A)this;
  }
  public java.util.List<java.lang.String> getUsers() {
    return this.users;
  }
  public java.lang.String getUser(java.lang.Integer index) {
    return this.users.get(index);
  }
  public java.lang.String getFirstUser() {
    return this.users.get(0);
  }
  public java.lang.String getLastUser() {
    return this.users.get(users.size() - 1);
  }
  public java.lang.String getMatchingUser(java.util.function.Predicate<java.lang.String> predicate) {
    for (java.lang.String item: users) { if(predicate.test(item)){ return item;} } return null;
  }
  public java.lang.Boolean hasMatchingUser(java.util.function.Predicate<java.lang.String> predicate) {
    for (java.lang.String item: users) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withUsers(java.util.List<java.lang.String> users) {
    if (users != null) {this.users = new java.util.ArrayList<java.lang.String>(); for (java.lang.String item : users){this.addToUsers(item);}} else { this.users = null;} return (A) this;
  }
  public A withUsers(java.lang.String... users) {
    if (this.users != null) {this.users.clear();}
    if (users != null) {for (java.lang.String item :users){ this.addToUsers(item);}} return (A) this;
  }
  public java.lang.Boolean hasUsers() {
    return users != null && !users.isEmpty();
  }
  public A addNewUser(java.lang.String arg0) {
    return (A)addToUsers(new String(arg0));
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    ResourceAccessReviewResponseFluentImpl that = (ResourceAccessReviewResponseFluentImpl) o;
    if (apiVersion != null ? !apiVersion.equals(that.apiVersion) :that.apiVersion != null) return false;
    if (evalutionError != null ? !evalutionError.equals(that.evalutionError) :that.evalutionError != null) return false;
    if (groups != null ? !groups.equals(that.groups) :that.groups != null) return false;
    if (kind != null ? !kind.equals(that.kind) :that.kind != null) return false;
    if (namespace != null ? !namespace.equals(that.namespace) :that.namespace != null) return false;
    if (users != null ? !users.equals(that.users) :that.users != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(apiVersion,  evalutionError,  groups,  kind,  namespace,  users,  additionalProperties,  super.hashCode());
  }
  
}

==> openshift-model-5.12.1-sources.jar: io/fabric8/openshift/api/model/ResourceAccessReviewResponseFluentImpl.java <==
package io.fabric8.openshift.api.model;

import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class ResourceAccessReviewResponseFluentImpl<A extends io.fabric8.openshift.api.model.ResourceAccessReviewResponseFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.ResourceAccessReviewResponseFluent<A>{
  public ResourceAccessReviewResponseFluentImpl() {
  }
  public ResourceAccessReviewResponseFluentImpl(io.fabric8.openshift.api.model.ResourceAccessReviewResponse instance) {
    this.withApiVersion(instance.getApiVersion()); 
    this.withEvalutionError(instance.getEvalutionError()); 
    this.withGroups(instance.getGroups()); 
    this.withKind(instance.getKind()); 
    this.withNamespace(instance.getNamespace()); 
    this.withUsers(instance.getUsers()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.lang.String apiVersion;
  private java.lang.String evalutionError;
  private java.util.List<java.lang.String> groups = new java.util.ArrayList<java.lang.String>();
  private java.lang.String kind;
  private java.lang.String namespace;
  private java.util.List<java.lang.String> users = new java.util.ArrayList<java.lang.String>();
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public java.lang.String getApiVersion() {
    return this.apiVersion;
  }
  public A withApiVersion(java.lang.String apiVersion) {
    this.apiVersion=apiVersion; return (A) this;
  }
  public java.lang.Boolean hasApiVersion() {
    return this.apiVersion != null;
  }
  
  /**
   * Method is deprecated. use withApiVersion instead.
   */
  @java.lang.Deprecated
  public A withNewApiVersion(java.lang.String arg0) {
    return (A)withApiVersion(new String(arg0));
  }
  public java.lang.String getEvalutionError() {
    return this.evalutionError;
  }
  public A withEvalutionError(java.lang.String evalutionError) {
    this.evalutionError=evalutionError; return (A) this;
  }
  public java.lang.Boolean hasEvalutionError() {
    return this.evalutionError != null;
  }
  
  /**
   * Method is deprecated. use withEvalutionError instead.
   */
  @java.lang.Deprecated
  public A withNewEvalutionError(java.lang.String arg0) {
    return (A)withEvalutionError(new String(arg0));
  }
  public A addToGroups(java.lang.Integer index,java.lang.String item) {
    if (this.groups == null) {this.groups = new java.util.ArrayList<java.lang.String>();}
    this.groups.add(index, item);
    return (A)this;
  }
  public A setToGroups(java.lang.Integer index,java.lang.String item) {
    if (this.groups == null) {this.groups = new java.util.ArrayList<java.lang.String>();}
    this.groups.set(index, item); return (A)this;
  }
  public A addToGroups(java.lang.String... items) {
    if (this.groups == null) {this.groups = new java.util.ArrayList<java.lang.String>();}
    for (java.lang.String item : items) {this.groups.add(item);} return (A)this;
  }
  public A addAllToGroups(java.util.Collection<java.lang.String> items) {
    if (this.groups == null) {this.groups = new java.util.ArrayList<java.lang.String>();}
    for (java.lang.String item : items) {this.groups.add(item);} return (A)this;
  }
  public A removeFromGroups(java.lang.String... items) {
    for (java.lang.String item : items) {if (this.groups!= null){ this.groups.remove(item);}} return (A)this;
  }
  public A removeAllFromGroups(java.util.Collection<java.lang.String> items) {
    for (java.lang.String item : items) {if (this.groups!= null){ this.groups.remove(item);}} return (A)this;
  }
  public java.util.List<java.lang.String> getGroups() {
    return this.groups;
  }
  public java.lang.String getGroup(java.lang.Integer index) {
    return this.groups.get(index);
  }
  public java.lang.String getFirstGroup() {
    return this.groups.get(0);
  }
  public java.lang.String getLastGroup() {
    return this.groups.get(groups.size() - 1);
  }
  public java.lang.String getMatchingGroup(java.util.function.Predicate<java.lang.String> predicate) {
    for (java.lang.String item: groups) { if(predicate.test(item)){ return item;} } return null;
  }
  public java.lang.Boolean hasMatchingGroup(java.util.function.Predicate<java.lang.String> predicate) {
    for (java.lang.String item: groups) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withGroups(java.util.List<java.lang.String> groups) {
    if (groups != null) {this.groups = new java.util.ArrayList(); for (java.lang.String item : groups){this.addToGroups(item);}} else { this.groups = null;} return (A) this;
  }
  public A withGroups(java.lang.String... groups) {
    if (this.groups != null) {this.groups.clear();}
    if (groups != null) {for (java.lang.String item :groups){ this.addToGroups(item);}} return (A) this;
  }
  public java.lang.Boolean hasGroups() {
    return groups != null && !groups.isEmpty();
  }
  public A addNewGroup(java.lang.String arg0) {
    return (A)addToGroups(new String(arg0));
  }
  public java.lang.String getKind() {
    return this.kind;
  }
  public A withKind(java.lang.String kind) {
    this.kind=kind; return (A) this;
  }
  public java.lang.Boolean hasKind() {
    return this.kind != null;
  }
  
  /**
   * Method is deprecated. use withKind instead.
   */
  @java.lang.Deprecated
  public A withNewKind(java.lang.String arg0) {
    return (A)withKind(new String(arg0));
  }
  public java.lang.String getNamespace() {
    return this.namespace;
  }
  public A withNamespace(java.lang.String namespace) {
    this.namespace=namespace; return (A) this;
  }
  public java.lang.Boolean hasNamespace() {
    return this.namespace != null;
  }
  
  /**
   * Method is deprecated. use withNamespace instead.
   */
  @java.lang.Deprecated
  public A withNewNamespace(java.lang.String arg0) {
    return (A)withNamespace(new String(arg0));
  }
  public A addToUsers(java.lang.Integer index,java.lang.String item) {
    if (this.users == null) {this.users = new java.util.ArrayList<java.lang.String>();}
    this.users.add(index, item);
    return (A)this;
  }
  public A setToUsers(java.lang.Integer index,java.lang.String item) {
    if (this.users == null) {this.users = new java.util.ArrayList<java.lang.String>();}
    this.users.set(index, item); return (A)this;
  }
  public A addToUsers(java.lang.String... items) {
    if (this.users == null) {this.users = new java.util.ArrayList<java.lang.String>();}
    for (java.lang.String item : items) {this.users.add(item);} return (A)this;
  }
  public A addAllToUsers(java.util.Collection<java.lang.String> items) {
    if (this.users == null) {this.users = new java.util.ArrayList<java.lang.String>();}
    for (java.lang.String item : items) {this.users.add(item);} return (A)this;
  }
  public A removeFromUsers(java.lang.String... items) {
    for (java.lang.String item : items) {if (this.users!= null){ this.users.remove(item);}} return (A)this;
  }
  public A removeAllFromUsers(java.util.Collection<java.lang.String> items) {
    for (java.lang.String item : items) {if (this.users!= null){ this.users.remove(item);}} return (A)this;
  }
  public java.util.List<java.lang.String> getUsers() {
    return this.users;
  }
  public java.lang.String getUser(java.lang.Integer index) {
    return this.users.get(index);
  }
  public java.lang.String getFirstUser() {
    return this.users.get(0);
  }
  public java.lang.String getLastUser() {
    return this.users.get(users.size() - 1);
  }
  public java.lang.String getMatchingUser(java.util.function.Predicate<java.lang.String> predicate) {
    for (java.lang.String item: users) { if(predicate.test(item)){ return item;} } return null;
  }
  public java.lang.Boolean hasMatchingUser(java.util.function.Predicate<java.lang.String> predicate) {
    for (java.lang.String item: users) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withUsers(java.util.List<java.lang.String> users) {
    if (users != null) {this.users = new java.util.ArrayList(); for (java.lang.String item : users){this.addToUsers(item);}} else { this.users = null;} return (A) this;
  }
  public A withUsers(java.lang.String... users) {
    if (this.users != null) {this.users.clear();}
    if (users != null) {for (java.lang.String item :users){ this.addToUsers(item);}} return (A) this;
  }
  public java.lang.Boolean hasUsers() {
    return users != null && !users.isEmpty();
  }
  public A addNewUser(java.lang.String arg0) {
    return (A)addToUsers(new String(arg0));
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    ResourceAccessReviewResponseFluentImpl that = (ResourceAccessReviewResponseFluentImpl) o;
    if (apiVersion != null ? !apiVersion.equals(that.apiVersion) :that.apiVersion != null) return false;
    if (evalutionError != null ? !evalutionError.equals(that.evalutionError) :that.evalutionError != null) return false;
    if (groups != null ? !groups.equals(that.groups) :that.groups != null) return false;
    if (kind != null ? !kind.equals(that.kind) :that.kind != null) return false;
    if (namespace != null ? !namespace.equals(that.namespace) :that.namespace != null) return false;
    if (users != null ? !users.equals(that.users) :that.users != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(apiVersion,  evalutionError,  groups,  kind,  namespace,  users,  additionalProperties,  super.hashCode());
  }
  
}
